Attribute VB_Name = "MParseO"

'   ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
'    ..........................................................
'     Application Name: Retrieve Modified Pages
'                       Rileva quali delle pagine HTML appartenenti alla lista data  variata dall'ultimo controllo.
'     Developer/Programmer: Simone Falchetti <S.Falchetti@iol.it>
'    ..........................................................
'     Module Name: MParseO
'     Module File: ParseO.bas
'     Module Type: Form
'     Module Description:
'    ..........................................................
'     (C) Copyright 2003
'    ..........................................................
'   ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

Option Explicit

'
' GetQToken:
'  Extracts tokens, including quoted tokens, from a string. A token
'  is a word that is surrounded by separators, such as spaces or commas.
'  Tokens are extracted and analyzed when parsing sentences or commands.
'  A quoted token is a group of characters surrounded by double quotes.
'  The quoted portion may contain the separator characters. To use the
'  GetQToken function, pass the string to be parsed on the first call,
'  then pass an empty string on subsequent calls until the function
'  returns an empty string to indicate that the entire string has been
'  parsed.
' Input:
'  sTarget = String to search
'  sSeps  = String of separators
' Output:
'  GetQToken = next token
'
'........................................
'Name: GetQToken
'Description:
'........................................
Function GetQToken(sTarget As String, sToken As String, sSeps As String) As Long

    ' Note that sSave and iStart must be static from call to call
    ' If first call, make copy of string
    Static sSave As String, iStart As Long, cSave As Long
    Dim iNew As Long, fQuote As Long
    If (sTarget <> sSave) Or (sSave = "") Then
        iStart = 1
        sSave = sTarget
        cSave = Len(sSave)
    End If
    sSeps = sSeps & """"

    GetQToken = False

    ' Find start of next token
    iNew = StrSpan2(Mid$(sSave, iStart, cSave), 1, sSeps)
    If iNew Then
        ' Set position to start of token
        iStart = iNew + iStart - 1
    Else
        ' If no new token, quit and return empty string
        sToken = ""
        Exit Function
    End If
    
    ' Find end of token
    If (iStart = 1) Then
        iNew = StrBreak2(Mid$(sSave, iStart, cSave), 1, sSeps)
    ElseIf Mid$(sSave, iStart - 1, 1) = """" Then
        iNew = StrBreak2(Mid$(sSave, iStart, cSave), 1, """")
    Else
        iNew = StrBreak2(Mid$(sSave, iStart, cSave), 1, sSeps)
    End If

    If iNew Then
        ' Set position to end of token
        iNew = iStart + iNew - 1
    Else
        ' If no end of token, return set to end a value
        iNew = cSave + 1
    End If
    ' Cut token out of sTarget string
    GetQToken = True
    sToken = Mid$(sSave, iStart, iNew - iStart)
    
    ' Set new starting position
    iStart = iNew

End Function

''@B GetToken
'........................................
'Name: GetToken
'Description:
'........................................
Function GetToken(sTarget As String, sSeps As String) As String
    
    ' Note that sSave and iStart must be static from call to call
    ' If first call, make copy of string
    Static sSave As String, iStart As Long, cSave As Long
    
    ' Assume failure
    GetToken = ""
    
    If sTarget <> "" Then
        iStart = 1
        sSave = sTarget
        cSave = Len(sSave)
    Else
        If sSave = "" Then Exit Function
    End If
    
    ' Find start of next token
    Dim iNew As Long
    ''@B CallStrSpan2
    iNew = StrSpan2(sSave, iStart, sSeps)
    ''@E CallStrSpan2
    If iNew Then
        ' Set position to start of token
        iStart = iNew
    Else
        ' If no new token, return empty string
        Exit Function
    End If
    
    ' Find end of token
    iNew = StrBreak2(sSave, iStart, sSeps)
    If iNew = 0 Then
        ' If no end of token, set to end of string
        iNew = cSave + 1
    End If
    ' Cut token out of sTarget string
    GetToken = Mid$(sSave, iStart, iNew - iStart)
    ' Set new starting position
    iStart = iNew

End Function ''@E GetToken


'........................................
'Name: StrBreak2
'Object: StrBreak2(sTarget As String, ByVal iStart As Long,
'Description:
'........................................
Function StrBreak2(sTarget As String, ByVal iStart As Long, _
                   sSeps As String) As Long
    
    Dim cTarget As Long
    cTarget = Len(sTarget)
   
    ''@B StrBreak2
    ' Look for end of token (first character that is a separator)
    Do While InStr(sSeps, Mid$(sTarget, iStart, 1)) = 0
    ''@E StrBreak2
        If iStart > cTarget Then
            StrBreak2 = 0
            Exit Function
        Else
            iStart = iStart + 1
        End If
    Loop
    StrBreak2 = iStart

End Function

''@B StrSpan2
'........................................
'Name: StrSpan2
'Object: StrSpan2(sTarget As String, ByVal iStart As Long,
'Description:
'........................................
Function StrSpan2(sTarget As String, ByVal iStart As Long, _
                  sSeps As String) As Long
    
    Dim cTarget As Long
    cTarget = Len(sTarget)
    ' Look for start of token (character that isn't a separator)
    ''@B CallMid
    Do While InStr(sSeps, Mid$(sTarget, iStart, 1))
    ''@E CallMid
        If iStart > cTarget Then
            StrSpan2 = 0
            Exit Function
        Else
            iStart = iStart + 1
        End If
    Loop
    StrSpan2 = iStart

End Function
''@E StrSpan2



' RemoveSigns(str As String, Optional bLowCase As Boolean) As String
' restituisce una stringa dalla quale sono stati
' eliminati tutti i caratteri numerici e simbolici.
Public Function RemoveSigns(str As String, Optional bLowCase As Boolean) As String
Dim i As Integer, iP As Integer


    For i = 1 To Len(str)
        iP = Asc(Mid$(str, i, 1))
        If ((iP > 64) And (iP < 91)) _
          Or ((iP > 96) And (iP < 123)) _
          Or ((iP > 47) And (iP < 58)) Then
            RemoveSigns = RemoveSigns & Chr$(iP)
        End If
    Next
    ' traspongo in minuscolo se specificato
    If bLowCase Then RemoveSigns = LCase$(RemoveSigns)
    ' elimino, qualora ci siano, i caratteri "http;//www.".
    iP = InStr(1, RemoveSigns, "www")
    If iP Then RemoveSigns = Mid$(RemoveSigns, iP + 3)

End Function
